# History of changes

## Version 0.2 (2017/01/31)

### Issues Closed

* [Issue 57](https://github.com/spyder-ide/loghub/issues/57) - Allow Enable/Disable of PR output
* [Issue 56](https://github.com/spyder-ide/loghub/issues/56) - Fix output for grouped labels if no items on that group
* [Issue 55](https://github.com/spyder-ide/loghub/issues/55) - Fix date on generation based on milestone
* [Issue 53](https://github.com/spyder-ide/loghub/issues/53) - Normalize CI files using requirements.txt
* [Issue 52](https://github.com/spyder-ide/loghub/issues/52) - Update README to use full commands
* [Issue 47](https://github.com/spyder-ide/loghub/issues/47) - Update Appveyor Badge for new username spyder-ide
* [Issue 46](https://github.com/spyder-ide/loghub/issues/46) - Create labels automagically on github based on template
* [Issue 42](https://github.com/spyder-ide/loghub/issues/42) - Generate all changelog based on milestones
* [Issue 41](https://github.com/spyder-ide/loghub/issues/41) - Add default template for release with issue label grouping
* [Issue 40](https://github.com/spyder-ide/loghub/issues/40) - Provide available milestones to user when provided not found
* [Issue 39](https://github.com/spyder-ide/loghub/issues/39) - Add checkignore to quantified code
* [Issue 30](https://github.com/spyder-ide/loghub/issues/30) - Add label groupings
* [Issue 28](https://github.com/spyder-ide/loghub/issues/28) - Generate all changelog based on tags
* [Issue 27](https://github.com/spyder-ide/loghub/issues/27) - Generate all changelog based on milestones
* [Issue 23](https://github.com/spyder-ide/loghub/issues/23) - Update Readme with new CLI parameters
* [Issue 21](https://github.com/spyder-ide/loghub/issues/21) - Add branch parameter to select PRs to display based on the merging branch
* [Issue 16](https://github.com/spyder-ide/loghub/issues/16) - Better authorization handling 
* [Issue 15](https://github.com/spyder-ide/loghub/issues/15) - Since tag not working properly
* [Issue 11](https://github.com/spyder-ide/loghub/issues/11) - Support hidden password
* [Issue 10](https://github.com/spyder-ide/loghub/issues/10) - Support custom line formats [templates]
* [Issue 8](https://github.com/spyder-ide/loghub/issues/8) - Support "all issues" 
* [Issue 4](https://github.com/spyder-ide/loghub/issues/4) - Expose labels for additional filtering
* [Issue 3](https://github.com/spyder-ide/loghub/issues/3) - Add access token interface
* [Issue 2](https://github.com/spyder-ide/loghub/issues/2) - Add some basic tests

In this release 24 issues were closed.

### Pull Requests Merged

* [PR 65](https://github.com/spyder-ide/loghub/pull/65) - PR: Add support for no-prs on output
* [PR 61](https://github.com/spyder-ide/loghub/pull/61) - PR: Add batch mode for all tags for all milestones
* [PR 60](https://github.com/spyder-ide/loghub/pull/60) - PR: Add requirements file and update CI process
* [PR 59](https://github.com/spyder-ide/loghub/pull/59) - PR: Add a label creator utility
* [PR 58](https://github.com/spyder-ide/loghub/pull/58) - PR: Refactor code and simplify group handling
* [PR 54](https://github.com/spyder-ide/loghub/pull/54) - PR: Remove versioneer
* [PR 51](https://github.com/spyder-ide/loghub/pull/51) - PR: Update ignore file to ignore versioneer files
* [PR 50](https://github.com/spyder-ide/loghub/pull/50) - PR: Add versioneer for version string control based on git tags not on manual editing
* [PR 48](https://github.com/spyder-ide/loghub/pull/48) - PR: Update AppVeyor badge because of move to org account
* [PR 45](https://github.com/spyder-ide/loghub/pull/45) - PR: Break into smaller funcs
* [PR 44](https://github.com/spyder-ide/loghub/pull/44) - PR: Improve error handling
* [PR 43](https://github.com/spyder-ide/loghub/pull/43) - PR: Add template for release grouped issue labels
* [PR 36](https://github.com/spyder-ide/loghub/pull/36) - PR: Update readme with latest CLI commands
* [PR 34](https://github.com/spyder-ide/loghub/pull/34) - PR: Add label grouping for issues 
* [PR 32](https://github.com/spyder-ide/loghub/pull/32) - PR: Feature/branch
* [PR 31](https://github.com/spyder-ide/loghub/pull/31) - PR: Refactor code
* [PR 29](https://github.com/spyder-ide/loghub/pull/29) - PR: Maintenance/tests
* [PR 20](https://github.com/spyder-ide/loghub/pull/20) - PR: Feature/templates
* [PR 19](https://github.com/spyder-ide/loghub/pull/19) - PR: Add support for all issues when no tag or no milestone is provided
* [PR 18](https://github.com/spyder-ide/loghub/pull/18) - PR: Add support for github tokens
* [PR 17](https://github.com/spyder-ide/loghub/pull/17) - PR: Add regex label filtering for issues and prs
* [PR 14](https://github.com/spyder-ide/loghub/pull/14) - add password prompt when user is specified and password is blank
* [PR 13](https://github.com/spyder-ide/loghub/pull/13) - PR: Fix bug on since keyword returning incorrect issues
* [PR 12](https://github.com/spyder-ide/loghub/pull/12) - Don't test macOS in Travis
* [PR 9](https://github.com/spyder-ide/loghub/pull/9) - Don't show "Issues" or "Pull requests" sections if there are no issues or PRs to show
* [PR 7](https://github.com/spyder-ide/loghub/pull/7) - Fix contents of temporary file
* [PR 6](https://github.com/spyder-ide/loghub/pull/6) - Remove extra empty lines
* [PR 5](https://github.com/spyder-ide/loghub/pull/5) - Fix PR_SHORT formatting.
* [PR 1](https://github.com/spyder-ide/loghub/pull/1) - Several fixes

In this release 29 pull requests were closed.

## Version 0.1.2 (2016/11/22)

### Bugs fixed

**Pull requests**

* [PR 12](https://github.com/spyder-ide/loghub/pull/12) - Don't test macOS in Travis
* [PR 9](https://github.com/spyder-ide/loghub/pull/9) - Don't show "Issues" or "Pull requests" sections if there are no issues or PRs to show
* [PR 7](https://github.com/spyder-ide/loghub/pull/7) - Fix contents of temporary file
* [PR 6](https://github.com/spyder-ide/loghub/pull/6) - Remove extra empty lines
* [PR 5](https://github.com/spyder-ide/loghub/pull/5) - Fix PR_SHORT formatting.

In this release 5 pull requests were merged

## Version 0.1.0

* Initial release
